I’m Charlie
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## About Me

**I’m a software developer and problem solver with a strong focus on
Python and data-driven solutions.** From building custom tools for data
visualization to optimizing real estate investment strategies with
complex calculations like levered IRR, I love finding creative,
efficient ways to tackle challenges. I have a deep interest in coding,
cloud technology, and real estate analytics, and I’m constantly learning
new ways to improve workflows and outcomes.

Outside of my work in tech, I’m a lifelong musician. I studied jazz
performance at NYU, and co-founded the band Del Water Gap. I’ve
performed with Maggie Rogers and have been gigging in NYC since I was
16, balancing my passion for music with my love for coding and
problem-solving.

**I made this site using NBDev**
